<?php

/**
 * @file
 * Contains \Drupal\cleantalk\Form\CleantalkCheckUsersForm.
 */

namespace Drupal\cleantalk\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;
use Drupal\user\Entity\User;

class CleantalkCheckUsersForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cleantalk_check_users_form';
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('cleantalk.settings');

    foreach (Element::children($form) as $variable) {
      $config->set($variable, $form_state->getValue($form[$variable]['#parents']));
    }
    $config->save();

    if (method_exists($this, '_submitForm')) {
      $this->_submitForm($form, $form_state);
    }

    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['cleantalk.settings'];
  }

  public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) {
    // @FIXME
    // Could not extract the default value because it is either indeterminate, or
    // not scalar. You'll need to provide a default value in
    // config/install/cleantalk.settings.yml and config/schema/cleantalk.schema.yml.
      $ct_authkey = \Drupal::config('cleantalk.settings')->get('cleantalk_authkey');
    if (!empty($ct_authkey)) {
        $form['find_spammers_users']  = array(
                '#type' => 'submit',
                '#value' => t('Check users'),
                '#submit' => array('::cleantalk_find_spammers_users'),
              );
                 if(isset($form_state->getStorage()['spam_users']))
  {
           
               $form['spam_users'] = array (
      '#type' => 'table',
      '#header' => array('Username','E-mail','Status','Registered','Last visit', ''),
      '#empty' => t('No users found'),
    );
               $spam_users = $form_state->getStorage()['spam_users'];
                   foreach ($spam_users as $user) {
                          // Show user ID
      $form['spam_users'][$user['id']][0] = array(
        '#type' => 'label',
        '#title' => $user['name'],
      );

      // Show user ID
      $form['spam_users'][$user['id']][1] = array(
        '#type' => 'label',
        '#title' => $user['mail'],
      );
            // Show user ID
      $form['spam_users'][$user['id']][2] = array(
        '#type' => 'label',
        '#title' => $user['status'],
      );
            // Show user ID
      $form['spam_users'][$user['id']][3] = array(
        '#type' => 'label',
        '#title' => $user['created'],
      );
                  // Show user ID
      $form['spam_users'][$user['id']][4] = array(
        '#type' => 'label',
        '#title' => $user['login'],
      );
            // Show button for each user
      $form['spam_users'][$user['id']]['removememberbutton']['dummyNode'] = array(
        '#type' => 'submit',
        '#value' => 'Remove',
        '#name' => 'remove_' . $user['id'],
        '#submit' => array('::cleantalk_remove_user'),
      );
    }
          $data = array();
            foreach ($spam_users as $user)
               array_push($data,$user['id']);
            $form['delete_all_spammers_users']  = array(
                '#type' => 'submit',
                '#value' => t('Delete all'),
                '#name' => 'delete_all_' . implode('_',$data),
                '#submit' => array('::cleantalk_delete_all_spammers_users'),
              );
      }
            }
            else drupal_set_message('Invalid CleanTalk access key!','error');
    return $form;
  }
  function cleantalk_find_spammers_users(array $form, \Drupal\Core\Form\FormStateInterface $form_state)
{
        $ct_authkey = \Drupal::config('cleantalk.settings')->get('cleantalk_authkey');
        if (isset($ct_authkey))
        {
          $ids = \Drupal::entityQuery('user')->execute();
          $users = User::loadMultiple($ids);
          $data = array();$spam_users=array();
          foreach ($users as $user)
            array_push($data,$user->get('mail')->value);
          $data=implode(',',$data);
          $request=Array();
          $request['method_name'] = 'spam_check_cms';
          $request['auth_key'] = $ct_authkey;
          $request['data'] = $data;
          $url='https://api.cleantalk.org';
          $result=sendRawRequest($url, $request);

          $result=json_decode($result);
          if(isset($result->error_message))
          {
            drupal_set_message($result->error_message,'error');
          }
          else
          {
            if (isset($result->data))
            {
              foreach($result->data as $mail=>$value)
              {
                if ($value->appears == '1' )
                {
                  foreach ($users as $user)
                  {
                    if ($user->get('mail')->value == $mail)
                      $spam_users[] = $user;
                  }
                }

              }               
            }
          }
          $storage_array = array();$id=0;
          foreach ($spam_users as $user)
          {
            $storage_array[$id]['id'] = $user->id();
            $storage_array[$id]['name'] = $user->get('name')->value;
            $storage_array[$id]['mail'] = $user->get('mail')->value;
            $storage_array[$id]['status'] = ($user->get('status')->value==1)?'Active':'Inactive';
            $storage_array[$id]['created'] = date("Y-m-d H:i:s",$user->get('created')->value);
            $storage_array[$id]['login'] = date("Y-m-d H:i:s",$user->get('login')->value);
            $id++;
          }
          $form_state->setStorage(array('spam_users'=>$storage_array));
          $form_state->setRebuild();          
        }

}

function cleantalk_remove_user(array $form, \Drupal\Core\Form\FormStateInterface $form_state ) {
    $userid = $form_state->getTriggeringElement()['#array_parents'][1];
        db_delete('users_field_data')
        ->condition('uid', $userid, '=')
        ->execute();
        db_delete('users_data')
        ->condition('uid', $userid, '=')
        ->execute();
        db_delete('users')
        ->condition('uid', $userid, '=')
        ->execute();
        db_delete('comment_field_data')
        ->condition('uid', $userid, '=')
        ->execute();

        $this->cleantalk_find_spammers_users($form,$form_state);
}
function cleantalk_delete_all_spammers_users(array $form, \Drupal\Core\Form\FormStateInterface $form_state ) {
    $post_array = str_replace('delete_all_', '', $form_state->getTriggeringElement()['#name']);
    $ids = explode('_',$post_array);
    foreach ($ids as $id)
    {
        db_delete('users_field_data')
        ->condition('uid', $id, '=')
        ->execute();
        db_delete('users_data')
        ->condition('uid', $id, '=')
        ->execute();
        db_delete('users')
        ->condition('uid', $id, '=')
        ->execute(); 
        db_delete('comment_field_data')
        ->condition('uid', $id, '=')
        ->execute();             
    }
            $this->cleantalk_find_spammers_users($form,$form_state);
}
}
